@@ -1,10 +1,5 @@
 ##
-# Copyright 2009-2012 Ghent University
-# Copyright 2009-2012 Stijn De Weirdt
-# Copyright 2010 Dries Verdegem
-# Copyright 2010-2012 Kenneth Hoste
-# Copyright 2011 Pieter De Baets
-# Copyright 2011-2012 Jens Timmerman
+# Copyright 2009-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -29,8 +24,13 @@
 ##
 """
 EasyBuild support for building and installing WPS, implemented as an easyblock
-"""
 
+@author: Stijn De Weirdt (Ghent University)
+@author: Dries Verdegem (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+@author: Pieter De Baets (Ghent University)
+@author: Jens Timmerman (Ghent University)
+"""
 import fileinput
 import os
 import re
@@ -219,10 +219,14 @@ class EB_WPS(EasyBlock):
 
         wpsdir = None
 
-        def run_wps_cmd(cmdname):
+        def run_wps_cmd(cmdname, mpi_cmd=True):
             """Run a WPS command, and check for success."""
 
             cmd = os.path.join(wpsdir, "%s.exe" % cmdname)
+            
+            if mpi_cmd:
+                cmd = self.toolchain.mpi_cmd_for(cmd, 1)
+            
             (out, _) = run_cmd(cmd, log_all=True, simple=False)
 
             re_success = re.compile("Successful completion of %s" % cmdname)
@@ -303,7 +307,7 @@ class EB_WPS(EasyBlock):
                 run_cmd(cmd, log_all=True, simple=True)
 
                 # run ungrib.exe
-                run_wps_cmd("ungrib")
+                run_wps_cmd("ungrib", mpi_cmd=False)
 
                 # METGRID.TBL
 
